==> cxf-testutils-2.3.1-patch-01-sources.jar: org/apache/cxf/greeter_control/types/ObjectFactory.java <==

package org.apache.cxf.greeter_control.types;

import javax.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the org.apache.cxf.greeter_control.types package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {


    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: org.apache.cxf.greeter_control.types
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link StopGreeter }
     * 
     */
    public StopGreeter createStopGreeter() {
        return new StopGreeter();
    }

    /**
     * Create an instance of {@link PingMe }
     * 
     */
    public PingMe createPingMe() {
        return new PingMe();
    }

    /**
     * Create an instance of {@link SayHiResponse }
     * 
     */
    public SayHiResponse createSayHiResponse() {
        return new SayHiResponse();
    }

    /**
     * Create an instance of {@link StartGreeterResponse }
     * 
     */
    public StartGreeterResponse createStartGreeterResponse() {
        return new StartGreeterResponse();
    }

    /**
     * Create an instance of {@link FaultDetail }
     * 
     */
    public FaultDetail createFaultDetail() {
        return new FaultDetail();
    }

    /**
     * Create an instance of {@link GreetMe }
     * 
     */
    public GreetMe createGreetMe() {
        return new GreetMe();
    }

    /**
     * Create an instance of {@link GreetMeResponse }
     * 
     */
    public GreetMeResponse createGreetMeResponse() {
        return new GreetMeResponse();
    }

    /**
     * Create an instance of {@link SayHi }
     * 
     */
    public SayHi createSayHi() {
        return new SayHi();
    }

    /**
     * Create an instance of {@link FaultLocation }
     * 
     */
    public FaultLocation createFaultLocation() {
        return new FaultLocation();
    }

    /**
     * Create an instance of {@link GreetMeOneWay }
     * 
     */
    public GreetMeOneWay createGreetMeOneWay() {
        return new GreetMeOneWay();
    }

    /**
     * Create an instance of {@link StartGreeter }
     * 
     */
    public StartGreeter createStartGreeter() {
        return new StartGreeter();
    }

    /**
     * Create an instance of {@link StopGreeterResponse }
     * 
     */
    public StopGreeterResponse createStopGreeterResponse() {
        return new StopGreeterResponse();
    }

    /**
     * Create an instance of {@link PingMeResponse }
     * 
     */
    public PingMeResponse createPingMeResponse() {
        return new PingMeResponse();
    }

}

==> cxf-testutils-2.4.8-patch-01-sources.jar: org/apache/cxf/greeter_control/types/ObjectFactory.java <==

package org.apache.cxf.greeter_control.types;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the org.apache.cxf.greeter_control.types package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private final static QName _RobustInOnlyMode_QNAME = new QName("http://cxf.apache.org/greeter_control/types", "robustInOnlyMode");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: org.apache.cxf.greeter_control.types
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link StartGreeter }
     * 
     */
    public StartGreeter createStartGreeter() {
        return new StartGreeter();
    }

    /**
     * Create an instance of {@link PingMeResponse }
     * 
     */
    public PingMeResponse createPingMeResponse() {
        return new PingMeResponse();
    }

    /**
     * Create an instance of {@link StartGreeterResponse }
     * 
     */
    public StartGreeterResponse createStartGreeterResponse() {
        return new StartGreeterResponse();
    }

    /**
     * Create an instance of {@link StopGreeter }
     * 
     */
    public StopGreeter createStopGreeter() {
        return new StopGreeter();
    }

    /**
     * Create an instance of {@link StopGreeterResponse }
     * 
     */
    public StopGreeterResponse createStopGreeterResponse() {
        return new StopGreeterResponse();
    }

    /**
     * Create an instance of {@link PingMe }
     * 
     */
    public PingMe createPingMe() {
        return new PingMe();
    }

    /**
     * Create an instance of {@link SayHi }
     * 
     */
    public SayHi createSayHi() {
        return new SayHi();
    }

    /**
     * Create an instance of {@link FaultLocation }
     * 
     */
    public FaultLocation createFaultLocation() {
        return new FaultLocation();
    }

    /**
     * Create an instance of {@link GreetMeOneWay }
     * 
     */
    public GreetMeOneWay createGreetMeOneWay() {
        return new GreetMeOneWay();
    }

    /**
     * Create an instance of {@link FaultDetail }
     * 
     */
    public FaultDetail createFaultDetail() {
        return new FaultDetail();
    }

    /**
     * Create an instance of {@link GreetMe }
     * 
     */
    public GreetMe createGreetMe() {
        return new GreetMe();
    }

    /**
     * Create an instance of {@link SayHiResponse }
     * 
     */
    public SayHiResponse createSayHiResponse() {
        return new SayHiResponse();
    }

    /**
     * Create an instance of {@link GreetMeResponse }
     * 
     */
    public GreetMeResponse createGreetMeResponse() {
        return new GreetMeResponse();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link Boolean }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://cxf.apache.org/greeter_control/types", name = "robustInOnlyMode")
    public JAXBElement<Boolean> createRobustInOnlyMode(Boolean value) {
        return new JAXBElement<Boolean>(_RobustInOnlyMode_QNAME, Boolean.class, null, value);
    }

}
